from .search import search_text
from .selection import get_selected_text
from .where import get_list_of_search_urls, get_search_url


def search_selected_text(where=None):
    where = get_search_url(where)
    text = get_selected_text()
    search_text(where, text)



from .environ import get_environment_variable

WHERE = {
    "Google": "https://www.google.com/search?q=",
    "WordReference": "https://www.wordreference.com/enfr/",
    "DeepL": "https://www.deepl.com/translator#en/fr/",
    "GoogleScholar": "https://scholar.google.com/scholar?q=",
}


DEFAULT_SEARCH_URL = get_environment_variable("DEFAULT_SEARCH_URL")


def get_default_search_url():
    return WHERE.get(DEFAULT_SEARCH_URL, None) or DEFAULT_SEARCH_URL or WHERE["Google"]


def get_search_url(name):
    return WHERE.get(name, None) or name or get_default_search_url()


def get_list_of_search_urls():
    max_len = max(map(len, WHERE.keys()))

    keys = sorted(WHERE.keys())

    return "\n".join(f"{key:{max_len}s} - {WHERE[key]}" for key in keys)


if __name__ == "__main__":

    print(get_list_of_search_urls())



from functools import partial

import click
from pynput.keyboard import GlobalHotKeys

from .main import search_selected_text

hotkeys = {
    "<ctrl>+m": search_selected_text,
    "<ctrl>+n": partial(search_selected_text, where="DeepL"),
    "<ctrl>+b": partial(search_selected_text, where="WordReference"),
}


@click.command()
def gui():
    """
    SelSearch's Graphical User Interface.

    Continuously runs in background.
    """
    with GlobalHotKeys(hotkeys) as listener:
        listener.join()



import os
import shutil
import time

import pyperclip
from pynput.keyboard import Controller, Key

keyboard = Controller()


def get_selected_text_xsel():
    return os.popen("xsel").read()


def get_selected_text_alt():
    clipboard = pyperclip.paste()

    keyboard.press(Key.ctrl)
    keyboard.press("c")
    time.sleep(0.1)
    keyboard.release("c")
    keyboard.release(Key.ctrl)
    text = pyperclip.paste()

    pyperclip.copy(clipboard)
    return text


if shutil.which("xsel"):
    get_selected_text = get_selected_text_xsel
else:
    get_selected_text = get_selected_text_alt



from setuptools import find_packages, setup

from selsearch import __version__ as version

with open("README.md", "r") as f:
    long_description = f.read()


setup(
    name="selsearch",
    author="Jérome Eertmans",
    author_email="jeertmans@icloud.com",
    version=version,
    packages=find_packages(),
    description="Internet search based on selected text",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/jeertmans/selsearch",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    license="MIT",
    python_requires=">=3.6",
    install_requires=[
        "click==8.0.3",
        "pyperclip==1.8.2",
        "pynput==1.7.6",
    ],
    entry_points="""
        [console_scripts]
        selsearch=app:cli
    """,
)
